@@ -5,14 +5,7 @@ from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
                                        WebSocketReqClient)
 from notecoin.huobi.constant import (CandlestickInterval, DepthStep,
                                      HttpMethod, MbpLevel)
-from notecoin.huobi.utils import (get_current_timestamp, kline_channel,
-                                  market_detail_channel,
-                                  price_depth_bbo_channel, price_depth_channel,
-                                  request_kline_channel,
-                                  request_market_detail_channel,
-                                  request_price_depth_channel,
-                                  request_trade_detail_channel,
-                                  trade_detail_channel)
+from notecoin.huobi.utils import get_current_timestamp
 from notecoin.huobi.utils.input_checker import (check_in_list, check_range,
                                                 check_should_not_none,
                                                 check_symbol,
@@ -78,6 +71,12 @@ class MarketClient(object):
         check_should_not_none(interval, "interval")
         check_should_not_none(callback, "callback")
 
+        def kline_channel(symbol, _interval):
+            channel = dict()
+            channel["sub"] = "market." + symbol + ".kline." + _interval
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(kline_channel(symbol, interval))
@@ -110,6 +109,16 @@ class MarketClient(object):
         check_should_not_none(interval, "interval")
         check_should_not_none(callback, "callback")
 
+        def request_kline_channel(symbol, _interval, _from_ts_second=None, to_ts_second=None):
+            channel = dict()
+            channel["req"] = "market." + symbol + ".kline." + _interval
+            channel["id"] = str(get_current_timestamp())
+            if _from_ts_second:
+                channel["from"] = int(_from_ts_second)
+            if to_ts_second:
+                channel["to"] = int(to_ts_second)
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(request_kline_channel(symbol, interval, from_ts_second, end_ts_second))
@@ -185,6 +194,12 @@ class MarketClient(object):
         step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
         check_should_not_none(callback, "callback")
 
+        def price_depth_channel(symbol, step_type=DepthStep.STEP0):
+            channel = dict()
+            channel["sub"] = "market." + symbol + ".depth." + step_type
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(price_depth_channel(symbol, step))
@@ -212,6 +227,12 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
+        def price_depth_bbo_channel(symbol):
+            channel = dict()
+            channel["sub"] = "market." + symbol + ".bbo"
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(price_depth_bbo_channel(symbol))
@@ -241,6 +262,12 @@ class MarketClient(object):
         step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
         check_should_not_none(callback, "callback")
 
+        def request_price_depth_channel(symbol, step_type="step0"):
+            channel = dict()
+            channel["req"] = "market." + symbol + ".depth." + step_type
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(request_price_depth_channel(symbol, step))
@@ -284,6 +311,12 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
+        def market_detail_channel(_symbol):
+            channel = dict()
+            channel["sub"] = "market." + _symbol + ".detail"
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(market_detail_channel(symbol))
@@ -310,6 +343,12 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
+        def request_market_detail_channel(_symbol):
+            channel = dict()
+            channel["req"] = "market." + _symbol + ".detail"
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(request_market_detail_channel(symbol))
@@ -373,6 +412,12 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
+        def trade_detail_channel(symbol):
+            channel = dict()
+            channel["sub"] = "market." + symbol + ".trade.detail"
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(trade_detail_channel(symbol))
@@ -399,6 +444,12 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
+        def request_trade_detail_channel(symbol):
+            channel = dict()
+            channel["req"] = "market." + symbol + ".trade.detail"
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
         def subscription(connection):
             for symbol in symbol_list:
                 connection.send(request_trade_detail_channel(symbol))
